==> qtjambi-webenginecore-6.5.1-sources.jar: io/qt/webengine/core/QWebEngineHistoryItem.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Represents one item in the history of a web engine page</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html">QWebEngineHistoryItem</a></p>
 */
public class QWebEngineHistoryItem extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#QWebEngineHistoryItem">QWebEngineHistoryItem::QWebEngineHistoryItem(QWebEngineHistoryItem)</a></p>
     */
    public QWebEngineHistoryItem(io.qt.webengine.core.@NonNull QWebEngineHistoryItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineHistoryItem instance, io.qt.webengine.core.QWebEngineHistoryItem other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#iconUrl">QWebEngineHistoryItem::iconUrl()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl iconUrl(){
        return iconUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl iconUrl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#isValid">QWebEngineHistoryItem::isValid()const</a></p>
     */
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#lastVisited">QWebEngineHistoryItem::lastVisited()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QDateTime lastVisited(){
        return lastVisited_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QDateTime lastVisited_native_constfct(long __this__nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.core.QWebEngineHistoryItem)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.core.@NonNull QWebEngineHistoryItem other) {
        assign(other);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#operator-eq">QWebEngineHistoryItem::operator=(QWebEngineHistoryItem)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineHistoryItem other){
        assign_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.core.@NonNull QWebEngineHistoryItem arg2){
        return operator_equal_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineHistoryItem(long __this__nativeId, long arg2);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#originalUrl">QWebEngineHistoryItem::originalUrl()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl originalUrl(){
        return originalUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl originalUrl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#swap">QWebEngineHistoryItem::swap(QWebEngineHistoryItem&amp;)</a></p>
     */
    @QtUninvokable
    public final void swap(io.qt.webengine.core.@StrictNonNull QWebEngineHistoryItem other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#title">QWebEngineHistoryItem::title()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#url">QWebEngineHistoryItem::url()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineHistoryItem(QPrivateConstructor p) { super(p); } 
    

    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineHistoryItem) {
            return operator_equal((io.qt.webengine.core.QWebEngineHistoryItem) other);
        }

        return false;
    }


    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineHistoryItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineHistoryItem clone_native(long __this_nativeId);
}

==> qtjambi-webenginecore-6.5.4-sources.jar: io/qt/webengine/core/QWebEngineHistoryItem.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Represents one item in the history of a web engine page</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html">QWebEngineHistoryItem</a></code></p>
 */
public class QWebEngineHistoryItem extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#QWebEngineHistoryItem">QWebEngineHistoryItem::<wbr/>QWebEngineHistoryItem(QWebEngineHistoryItem)</a></code></p>
     */
    public QWebEngineHistoryItem(io.qt.webengine.core.@NonNull QWebEngineHistoryItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineHistoryItem instance, io.qt.webengine.core.QWebEngineHistoryItem other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#iconUrl">QWebEngineHistoryItem::<wbr/>iconUrl()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl iconUrl(){
        return iconUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl iconUrl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#isValid">QWebEngineHistoryItem::<wbr/>isValid()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#lastVisited">QWebEngineHistoryItem::<wbr/>lastVisited()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QDateTime lastVisited(){
        return lastVisited_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QDateTime lastVisited_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#operator-eq">QWebEngineHistoryItem::<wbr/>operator=(QWebEngineHistoryItem)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineHistoryItem other){
        assign_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QWebEngineHistoryItem,<wbr/>QWebEngineHistoryItem)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.webengine.core.@NonNull QWebEngineHistoryItem arg2){
        return equals_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QWebEngineHistoryItem(long __this__nativeId, long arg2);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#originalUrl">QWebEngineHistoryItem::<wbr/>originalUrl()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl originalUrl(){
        return originalUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl originalUrl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#swap">QWebEngineHistoryItem::<wbr/>swap(QWebEngineHistoryItem&amp;)</a></code></p>
     */
    @QtUninvokable
    public final void swap(io.qt.webengine.core.@StrictNonNull QWebEngineHistoryItem other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#title">QWebEngineHistoryItem::<wbr/>title()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginehistoryitem.html#url">QWebEngineHistoryItem::<wbr/>url()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineHistoryItem(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QWebEngineHistoryItem,<wbr/>QWebEngineHistoryItem)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineHistoryItem) {
            return equals((io.qt.webengine.core.QWebEngineHistoryItem) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineHistoryItem)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineHistoryItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineHistoryItem clone_native(long __this_nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.core.QWebEngineHistoryItem)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.core.@NonNull QWebEngineHistoryItem other) {
        assign(other);
    }
}
